==> bribery-0.4.0%2B1.20.4-fabric-sources.jar: dev/spagurder/bribery/mixin/ServerPlayerMixin.java <==
package dev.spagurder.bribery.mixin;

import dev.spagurder.bribery.state.BribeData;
import dev.spagurder.bribery.state.BriberyState;
import net.minecraft.class_1282;
import net.minecraft.class_1309;
import net.minecraft.class_1928;
import net.minecraft.class_2561;
import net.minecraft.class_3222;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_3222.class)
public class ServerPlayerMixin {

    @Inject(method = "die", at = @At("HEAD"))
    public void beforeDie(class_1282 damageSource, CallbackInfo ci) {
        class_3222 player = (class_3222)(Object)this;
        //? >1.21.5 {
        /*if (!player.level().getGameRules().getBoolean(GameRules.RULE_SHOWDEATHMESSAGES)) return;
        *///?} else {
        if (!player.method_51469().method_8450().method_8355(class_1928.field_19398)) return;
        //?}
        if (!(damageSource.method_5529() instanceof class_1309 entity)) return;
        BribeData state = BriberyState.getBribeData(entity.method_5667(), player.method_5667());
        if (state == null) return;
        if (state.isRejected) {
            player.method_5682().method_3760().method_43514(
                    class_2561.method_43473()
                            .method_10852(player.method_5476())
                            .method_27693(" tried to bribe ")
                            .method_10852(entity.method_5476()),
                    false
            );
        }
    }

}

==> bribery-0.5.1%2B1.20.1-fabric-sources.jar: dev/spagurder/bribery/mixin/ServerPlayerMixin.java <==
package dev.spagurder.bribery.mixin;

import dev.spagurder.bribery.core.BriberyUtil;
import dev.spagurder.bribery.state.BribeData;
import dev.spagurder.bribery.state.BriberyState;
import net.minecraft.class_1282;
import net.minecraft.class_1309;
import net.minecraft.class_1928;
import net.minecraft.class_2561;
import net.minecraft.class_3222;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_3222.class)
public class ServerPlayerMixin {

    @Inject(method = "die", at = @At("HEAD"))
    public void beforeDie(class_1282 damageSource, CallbackInfo ci) {
        class_3222 player = (class_3222)(Object)this;
        //? >1.21.5 {
        /*if (!player.level().getGameRules().getBoolean(GameRules.RULE_SHOWDEATHMESSAGES)) return;
        *///?} else {
        if (!player.method_51469().method_8450().method_8355(class_1928.field_19398)) return;
        //?}
        if (!(damageSource.method_5529() instanceof class_1309 entity)) return;
        BribeData state = BriberyState.getBribeData(entity.method_5667(), player.method_5667());
        if (state == null) return;
        if (state.isRejected) {
            BriberyUtil.getEntityServer(player).method_3760().method_43514(
                    class_2561.method_43473()
                            .method_10852(player.method_5476())
                            .method_27693(" tried to bribe ")
                            .method_10852(entity.method_5476()),
                    false
            );
        }
    }

}
